; JAWS scripts for SecureCRT
; Written by Harald.van.Breederode@Oracle.com

; Version 1.0  8-dec-2004 Initial coding
; Version 1.1 12-mar-2005Added SecureCRT Version 5 support

include "HjConst.jsh" ; Load the default JAWS constants
include "ssh.jsm" ; Load our messages

const cSecureCRTWindowClass=  "AfxFrameOrView42" ; This is the Window class of SecureCRT

globals
	int iSecCrtForTheFirstTime, ; Is this the first time our scripts are being loaded?
	int iSecCrtNewTextWillBeSpoken ; Do we automaticly speak new text?

; This script is  called by JawsKey+Q
; This script announces the currently active JAWS settings
Script ScriptFilename ()
	ScriptAndAppNames ("SecureCRT") ; Announce that the SecureCRT settings are active
EndScript

; This function is activated when SecureCRT becomes active. Either when the program starts or when it gets focus again.
Void Function AutoStartEvent ()
	If (iSecCrtForTheFirstTime == 0)	then ; Is this our first time?
		SayMessage (OT_APP_START, msgSecureCRTTutor) ; Speak our welcome message
		let iSecCrtForTheFirstTime = 1 ; We do this only once
		let iSecCrtNewTextWillBeSpoken = 1 ; By default we speak new text that appears on the screen
	EndIf
	SaveCursor () ; Place the current active cursor on the cursor stack
	JAWSCursor (); Activate the JAWS cursor
	SetRestriction (RestrictWindow) ; Restrict the JawsCursor to the main window
	RestoreCursor () ; Re activate the previous cursor
	; We dont want to hear the screen contents again when we switch into SecureCRT from another application
	SpeechOff () ; Turn the speech off
	Pause () ; Let NewTextEvent do its job (silently)
	SpeechOn (); Turn the speech back on
	Saystring(GetAppTitle ()) ; Speak the WindowTitle so we know where we are
EndFunction

; This function is called when new text appears on the computer screen. Not just new text within SecureCRT.
Void Function NewTextEvent (handle hWnd,  string sBuffer,  int iAttributes
,  int iTextColor,  int iBackgroundColor,  int iEcho,  string sFrameName)
; Is the new text within SecureCRT?
	If (GetWindowClass (hwnd) == cSecureCRTWindowClass) then ; Yes
		If (iSecCrtNewTextWillBeSpoken) then ; Do wwe need to speak it?
			SayMessage (OT_SCREEN_MESSAGE,sBuffer) ; Yes
		EndIf
		Return ; We handled new SecureCRT text
	EndIf
; Everything we did not handled yet gets passed to the default function
	NewTextEvent (hWnd, sBuffer,  iAttributes,  iTextColor,  iBackgroundColor
	, iEcho,  sFrameName)
EndFunction

; This function is called when the active cursor hits the top ot the window
Void Function TopEdgeEvent (handle hWnd)
; We handle this only if the JAWScursor is active
	If  !( IsJAWSCursor () ) then
		Return ; Nothing to do unless the JAWS cursor is active
	EndIf
; Did the event go off in SecureCRT?
	If (GetWindowClass (hwnd) == cSecureCRTWindowClass) then ; Yes
		{Control+PageUp} ; scroll the screen one row down
	SpeechOff () ; Turn the speach of
		Pause () ; NewTextEvent do its job (silently)
		SpeechOn () ; Turn the speech back on
	EndIf
EndFunction

; This function is called when the active cursor hits the bottom of the window.
Void Function BottomEdgeEvent (handle hWnd)
; We handle this only if the JAWScursor is active
	If  !( IsJAWSCursor () ) then
		Return ; Nothing to do unless the JAWS cursor is active
	EndIf
; Did the event go off in SecureCRT?
	If (GetWindowClass (hwnd) == cSecureCRTWindowClass) then ; Yes
		{Control+PageDown} ; Scroll the screen one row up
		SpeechOff () ; Turn the speech off
		Pause (); Let NewTextEvent do its job (silently)
		SpeechOn () ; Turn the speech back on
	EndIf
EndFunction

; This script is called by JAWSKey+X
; It is used to toggle the new text being spoken on or off.
Script ToggleSpeechOnOrOff ()
	If (iSecCrtNewTextWillBeSpoken == 0) then ; Is it Off?
		let iSecCrtNewTextWillBeSpoken = 1; Turn it On
		SayMessage (OT_STATUS,msgSpeechOn_L,msgSpeechOn_S) ; announce the new setting
	Else
		let iSecCrtNewTextWillBeSpoken = 0 ; Turn if Off
		SayMessage (OT_STATUS,msgSpeechOff_L,msgSpeechOff_S) ; Announce the new setting
	EndIf
EndScript

; This is called by JAWSKey+H
; It places the hotkeys used by these scripts in a help window
Script HotKeyHelp ()
	If UserBufferIsActive () then ; If the help window is already active
		UserBufferDeactivate (); Remove it
	EndIf
	SayFormattedMessage (OT_USER_BUFFER, msgHotKeyHelp) ; Place our message in the help window and activate it
EndScript

; This is called by JAWSKey+F1
; It places some genaral help into the help window
Script ScreenSensitiveHelp ()
	If UserBufferIsActive () then ; If the help window is already active
		UserBufferDeactivate () ; remove it
	EndIf
	SayFormattedMessage (OT_USER_BUFFER, msgScreenSensitiveHelp) ; Place our help message in the help window and activate it
EndScript

; This script is called by JAWSKey+P
; It is used to change the JAWS punctuation setting
Script ChangePunctuation ()
	PerformScript SetPunctuationLevel () ; Call the script in the default script file
EndScript

; This script is called by Control+TAB
; It is used to switch between SecureCRT sessions
Script ControlTab ()
	TypeCurrentScriptKey () ; Pass Control+TAB to SecureCRT
	SpeechOff () ; Turn the speech off
	Pause () ; Let NewTextEvent do its job (silently)
	SpeechOn () ; turn the speech back on
	SayString(GetAppTitle ()) ; Announce the session name which we switched to
EndScript

; This script is called by the rightArrowKey
Script RightArrow ()
	If (GetWindowClass (GetFocus ()) == cSecureCRTWindowClass) then ; Are we in the terminal screen?
		If IsPCCursor () then ; And is the PC cursor active?
			SpeechOff () ; turn the speech off
			TypeCurrentScriptKey () ; pass the key to SecureCRT
			Pause () ; Let NewTextEvent do its job (silently)
			SpeechOn () ; Turn the speech back on
			SayCharacter () ; Speak the character we moved to
		Else ; For the other cursors
			PerformScript SayNextCharacter() ; Call the default script
		EndIf
	Else ; In case we were not in the terminal window
		PerformScript SayNextCharacter() ; call the default script
	EndIf
EndScript

; This script is called by the LeftArrowKey
Script LeftArrow ()
	If (GetWindowClass (GetFocus ()) == cSecureCRTWindowClass) then ; Are we in the terminal window?
		If IsPCCursor () then ; And is the PC cursor active?
		SpeechOff () ; Turn the speech off
			TypeCurrentScriptKey () ; pass the key to SecureCRT
			Pause () ; let NewTextEvent do its job (silently)
			SpeechOn () ; Turn the speech back on
			SayCharacter () ; speak the character we moved to
		Else ; for the other cursors 
			PerformScript SayPriorCharacter() ; call the default script
		EndIf
	Else ; In case we were not in the terminal window
		PerformScript SayPriorCharacter() ; call the default script
	EndIf
EndScript

; This is call by the UpArrowKey
Script UpArrow ()
	If (GetWindowClass (GetFocus ()) == cSecureCRTWindowClass) then ; Are we in the terminal window?
		If IsPCCursor () then ; And is the PC cursor active?
		SpeechOff () ; Turn the speech off
			TypeCurrentScriptKey () ; pass the key to SecureCRT
			Pause () ; let NewTextEvent do its job (silently)
			SpeechOn () ; turn the speech back on
			SayLine () ; speak the line we moved to
		Else ; for the other cursors
			PerformScript SayPriorLine() ; call the default scripts
		EndIf
	Else ; in case we were not in the terminal window
	PerformScript SayPriorLine(); call the default script
	EndIf
EndScript

; This script is called by the DownArrowKey
Script DownArrow ()
	If (GetWindowClass (GetFocus ()) == cSecureCRTWindowClass) then; Are we in the terminal window?
		If IsPCCursor () then ; And is the PC cursor active?
		SpeechOff () ; Turn the speech off
			TypeCurrentScriptKey () ; pass the key to SecureCRT
			Pause () ; let NewTextEvent do its job (silently)
			SpeechOn () ; Turn the speech back on
			SayLine () ; speak the line we moved to
		Else ; for the other cursors
			PerformScript SayNextLine() ; call the default script
		EndIf
	Else ; in case we were not in the terminal window 
		PerformScript SayNextLine() ; call the default script
	EndIf
EndScript
